@@ -10,14 +10,14 @@ loop = asyncio.get_event_loop()
 
 class QueryClient(LunarClient):
     """
-    Client for Lunar Data API (`/v1/query`).
+    Client for BAP Data API (`/v1/query`).
 
     ## Example
 
     ```python
-    import lunar
+    import bap
 
-    client = lunar.client("query")
+    client = bap.client("query")
     ```
     """
 
